HttpMethods class

Constructors

HttpMethods()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

client ↔ Client
getter/setter pair

Static Methods

deleteMethod(String url, String token) Future
getMethods(String url, String token, String orgId, String schemeId) Future
postMethods(dynamic data, String url, String token, String orgId, String schemeId) Future
postMethodsForUploadBill(String url, File imageFile) Future
putMethods(dynamic data, String url, String token, String orgId, String schemeId) Future